@@ -158,11 +158,15 @@ class Importer(BaseAction):
             return True
         return False
 
-    def wait_for_units(self, ignore_errors=False):
+    def check_timeout(self):
         timeout = self.options.timeout - (time.time() - self.start_time)
         if timeout < 0:
             self.log.error("Reached deployment timeout.. exiting")
             raise ErrorExit()
+        return timeout
+
+    def wait_for_units(self, ignore_errors=False):
+        timeout = self.check_timeout()
         # Set up the callback to be called in case of unit errors: if
         # ignore_errors is True errors are just logged, otherwise we exit the
         # program.
@@ -177,15 +181,16 @@ class Importer(BaseAction):
     def run(self):
         options = self.options
         self.start_time = time.time()
-        if options.bootstrap:
-            self.env.bootstrap()
-        self.env.connect()
 
         # Get charms
         self.get_charms()
         if options.branch_only:
             return
 
+        if options.bootstrap:
+            self.env.bootstrap()
+        self.env.connect()
+
         self.deploy_services()
 
         # Workaround api issue in juju-core, where any action takes 5s
@@ -198,6 +203,13 @@ class Importer(BaseAction):
         self.log.debug("Waiting for units before adding relations")
         self.wait_for_units(ignore_errors=ignore_errors)
 
+        # Reset our environment connection, as it may grow stale during
+        # the watch (we're using a sync client so not responding to pings
+        # unless actively using the conn).
+        self.env.close()
+        self.env.connect()
+
+        self.check_timeout()
         rels_created = self.add_relations()
 
         # Wait for the units to be up before waiting for rel stability.
