@@ -111,27 +111,32 @@ class Deployment(object):
 
     def get_charms(self):
         for k, v in self.data.get('services', {}).items():
-            yield Charm.from_service(k, self.series_path, v)
+            yield Charm.from_service(k, self.repo_path, self.series, v)
 
     def get_charm_for(self, svc_name):
         svc_data = self.data['services'][svc_name]
-        return Charm.from_service(svc_name, self.series_path, svc_data)
+        return Charm.from_service(
+            svc_name, self.repo_path, self.series, svc_data)
 
     def fetch_charms(self, update=False, no_local_mods=False):
-        if not os.path.exists(self.series_path):
-            os.mkdir(self.series_path)
         for charm in self.get_charms():
             if charm.is_local():
                 if charm.exists():
-                    if no_local_mods:
-                        if charm.is_modified():
-                            self.log.warning(
-                                "Charm %r has local modifications",
-                                charm.path)
+                    if no_local_mods and charm.is_modified():
+                        self.log.warning(
+                            "Charm %r has local modifications",
+                            charm.path)
+                        raise ErrorExit()
+                    if charm.rev or update:
+                        if charm.rev and charm.is_modified():
+                            self.log.warning((
+                                "Charm %r with pinned revision has"
+                                " local modifications"), charm.path)
                             raise ErrorExit()
-                    if update:
                         charm.update(build=True)
                     continue
+                elif not os.path.exists(charm.series_path):
+                    os.mkdir(charm.series_path)
             charm.fetch()
 
     def resolve(self, cli_overides=()):
