@@ -1,5 +1,6 @@
 import os
 import logging
+import subprocess
 
 from deployer.charm import Charm
 from deployer.utils import ErrorExit, yaml_dump
@@ -17,6 +18,11 @@ class Bzr(BaseBzr):
         self._call(
             ["bzr", "init", self.path],
             "Could not initialize repo at  %(path)s")
+        try:
+            subprocess.check_call(["bzr", "whoami"])
+        except subprocess.CalledProcessError:
+            subprocess.check_call([
+                "bzr", "whoami", "TestRunner <test@example.com>"])
 
     def write(self, files):
         for f in files:
